@@ -14,9 +14,9 @@ describe 'vitrage::wsgi::apache' do
         :path                        => '/',
         :servername                  => facts[:fqdn],
         :ssl                         => true,
-        :threads                     => facts[:os_workers],
+        :threads                     => 1,
         :user                        => 'vitrage',
-        :workers                     => 1,
+        :workers                     => facts[:os_workers],
         :wsgi_daemon_process         => 'vitrage',
         :wsgi_process_group          => 'vitrage',
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
@@ -56,7 +56,7 @@ describe 'vitrage::wsgi::apache' do
         :path                        => '/',
         :servername                  => 'dummy.host',
         :ssl                         => false,
-        :threads                     => facts[:os_workers],
+        :threads                     => 1,
         :user                        => 'vitrage',
         :workers                     => 37,
         :wsgi_daemon_process         => 'vitrage',
@@ -97,30 +97,13 @@ describe 'vitrage::wsgi::apache' do
             :wsgi_script_source => '/usr/share/vitrage-common/app.wsgi'
           }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            {
-              :httpd_service_name => 'httpd',
-              :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
-              :wsgi_script_path   => '/var/www/cgi-bin/vitrage',
-              :wsgi_script_source => '/usr/lib/python3.6/site-packages/vitrage/api/app.wsgi'
-            }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              {
-                :httpd_service_name => 'httpd',
-                :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
-                :wsgi_script_path   => '/var/www/cgi-bin/vitrage',
-                :wsgi_script_source => '/usr/lib/python3.6/site-packages/vitrage/api/app.wsgi'
-              }
-            else
-              {
-                :httpd_service_name => 'httpd',
-                :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
-                :wsgi_script_path   => '/var/www/cgi-bin/vitrage',
-                :wsgi_script_source => '/usr/lib/python2.7/site-packages/vitrage/api/app.wsgi'
-              }
-            end
-          end
+          {
+            :httpd_service_name => 'httpd',
+            :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
+            :wsgi_script_path   => '/var/www/cgi-bin/vitrage',
+            :wsgi_script_source => '/usr/lib/python2.7/site-packages/vitrage/api/app.wsgi'
+          }
+
         end
       end
       it_configures 'apache serving vitrage with mod_wsgi'
